@@ -76,7 +76,7 @@ makeBordered2
         :: (Source r1 a, Source r2 a)
         => DIM2                 -- ^ Extent of array.
         -> Int                  -- ^ Width of border.
-        -> Array r1 DIM2 a      -- ^ Array for internal elements.
+        -> Array r1 DIM2 a      -- ^ Array for internal elements.
         -> Array r2 DIM2 a      -- ^ Array for border elements.
         -> Array (P r1 (P r2 (P r2 (P r2 (P r2 X))))) DIM2 a
 
