@@ -1,5 +1,3 @@
-{-# LANGUAGE    MagicHash, PatternGuards, BangPatterns, TemplateHaskell, QuasiQuotes,
-                ParallelListComp, TypeOperators, ExplicitForAll, ScopedTypeVariables #-}
 {-# OPTIONS -Wnot #-}
 
 -- | Efficient computation of stencil based convolutions.
@@ -14,6 +12,5 @@ where
 import Data.Array.Repa
 import Data.Array.Repa.Base
 import Data.Array.Repa.Stencil.Base
-import Data.Array.Repa.Stencil.Template
 import Data.Array.Repa.Specialised.Dim2
 
